otel

package module
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func TracingMiddleware

func TracingMiddleware(tracer trace.Tracer) subscription.Middleware

TracingMiddleware creates a subscription middleware that traces event handling.

Types

type TracedCommandHandler

type TracedCommandHandler[S any] struct {
	// contains filtered or unexported fields
}

TracedCommandHandler wraps a CommandHandler with OpenTelemetry tracing and metrics.

func TraceCommands

func TraceCommands[S any](inner command.CommandHandler[S], tracer trace.Tracer, meter metric.Meter) *TracedCommandHandler[S]

TraceCommands wraps a command handler with tracing and metrics.

func (*TracedCommandHandler[S]) Handle

func (t *TracedCommandHandler[S]) Handle(ctx context.Context, cmd any) (*command.Result[S], error)

Jump to